ValidatorOptions class

Constructors

ValidatorOptions({RegExp? emailRegExp, RegExp? phoneRegExp, RegExp? ipv4RegExp, RegExp? ipv6RegExp, RegExp? urlRegExp})

Properties

emailRegExp RegExp
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
ipv4RegExp RegExp
getter/setter pair
ipv6RegExp RegExp
getter/setter pair
phoneRegExp RegExp
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
urlRegExp RegExp
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited