shaju_de library

Classes

ShajuDeButton
ShajuDe Design System's button, with haptic feedback, tooltip, taping area, and more. The button have 5 types: primary, secondary, and warning. The button have 5 types of haptic feedback: lightImpact, mediumImpact, heavyImpact, selectionClick, and none.
ShajuDeMobileFelid
Mobile Number Input The ShajuDeMobileFelid is a text field widget that allows the user to enter a mobile number. It provides various UX and UI features such as haptic feedback, validation, auto-fill hint, and country code display.

Enums

ButtonType